/*
 * Copyright (C) 2020, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef MYPUSHBUTTON_H
#define MYPUSHBUTTON_H

#include <QPushButton>
#include <QMouseEvent>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QWidget>
#include <QMessageBox>
#include "clipboard.h"

class MyPushButton : public QPushButton {
    Q_OBJECT

public:
    MyPushButton(QWidget* parent = nullptr);

protected:
    void mousePressEvent(QMouseEvent *event) override;
    void contextMenuEvent(QContextMenuEvent *event) override;

signals:
    void leftButtonClicked();
    void rightButtonClicked();
    void sigSelectWidgetClose();
    void sigHomePageShow();
    void sigSettingShow();
    void sigDisableScribe();

public:
    QMenu *settingRightClickMenu = nullptr;
    QAction *homePageAction = nullptr;
    QAction *disableAction = nullptr;
    QAction *settingAction = nullptr;
    QAction *closeAction = nullptr;
    QAction *selectedAction = nullptr;

private:
    Clipboard *selectClip = nullptr;

private slots:

};
#endif // MYPUSHBUTTON_H
